"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResourceSerializer = void 0;
class ResourceSerializer {
    constructor(options) {
        this.options = options;
    }
    parseOne(resource) {
        const id = resource.id;
        const type = this.contextEntity().name;
        // Attributes
        const attributes = resource;
        delete attributes.id;
        // One to One Relationships
        Object.keys(this.contextOneToOne()).forEach((key) => {
            delete attributes[key];
        });
        // One to Many Relationships
        Object.keys(this.contextOneToMany()).forEach((key) => {
            delete attributes[key];
        });
        return { id, type, attributes };
    }
    parseMany(resources) {
        return resources.map((resource) => {
            const id = resource.id;
            const type = this.contextEntity().name;
            // Attributes
            const attributes = resource;
            delete attributes.id;
            // One to One Relationships
            Object.keys(this.contextOneToOne()).forEach((key) => {
                delete attributes[key];
            });
            // One to Many Relationships
            Object.keys(this.contextOneToMany()).forEach((key) => {
                delete attributes[key];
            });
            return { id, type, attributes };
        });
    }
    contextEntity() {
        const entity = Reflect.getMetadata('JSONAPI_ENTITY', this.options.entity);
        if (!entity) {
            throw new Error('JSON-API-Transformer could not resolve the entity type. Did you add an @Entity annotation?');
        }
        else {
            return entity;
        }
    }
    contextOneToOne() {
        return Reflect.getMetadata('JSONAPI_ONE_TO_ONE', this.options.entity);
    }
    contextOneToMany() {
        return Reflect.getMetadata('JSONAPI_ONE_TO_MANY', this.options.entity);
    }
}
exports.ResourceSerializer = ResourceSerializer;
//# sourceMappingURL=resource.serializer.js.map